@@ -57,7 +57,7 @@ class BrCosmetic:
         The featured image in 1024x1024 resolution of the cosmetic.
     background: Optional[:class:`BrCosmeticImage`]
         The background image in 2048x1024 resolution of a loading screen.
-    cover_art: Optional[:class:`BrCosmeticImage`]
+    coverart: Optional[:class:`BrCosmeticImage`]
         The cover art image in 512x512 resolution of a music pack.
     decal: Optional[:class:`BrCosmeticImage`]
         The decal in 512x512 resolution of a spray.
@@ -79,6 +79,9 @@ class BrCosmetic:
         self.id = data.get('id')
         self.name = data.get('name')
         self.description = data.get('description')
+        self.exclusive_description = data.get('exclusiveDescription')
+        self.unlock_requirements = data.get('unlockRequirements')
+        self.custom_exclusive_callout = data.get('customExclusiveCallout')
 
         cosmetic_type = data.get('type', {}) if data.get('type') else {}
         try:
@@ -118,18 +121,23 @@ class BrCosmetic:
         self.featured = BrCosmeticImage(images.get('featured')) if images.get('featured') else None
         other_images = images.get('other', {}) if images.get('other') else {}
         self.background = BrCosmeticImage(other_images.get('background')) if other_images.get('background') else None
-        self.cover_art = BrCosmeticImage(other_images.get('coverart')) if other_images.get('coverart') else None
+        self.coverart = BrCosmeticImage(other_images.get('coverart')) if other_images.get('coverart') else None
         self.decal = BrCosmeticImage(other_images.get('decal')) if other_images.get('decal') else None
-        self.background = BrCosmeticImage(other_images.get('background')) if other_images.get('background') else None
 
         self.variants = [BrCosmeticVariant(variant) for variant in data.get('variants')] \
             if data.get('variants') is not None else None
+        self.built_in_emote_ids = [be for be in data.get('builtInEmoteIds')] \
+            if data.get('builtInEmoteIds') is not None else None
+        self.search_tags = [st for st in data.get('searchTags')] \
+            if data.get('searchTags') is not None else None
         self.gameplay_tags = [gameplay_tag for gameplay_tag in data.get('gameplayTags')] \
             if data.get('gameplayTags') is not None else None
         self.meta_tags = [meta_tag for meta_tag in data.get('metaTags')] \
             if data.get('metaTags') is not None else None
-        self.showcase_video = 'https://youtube.com/watch?v=' + data.get('showcaseVideo') \
+        self.showcase_video_url = 'https://youtube.com/watch?v=' + data.get('showcaseVideo') \
             if data.get('showcaseVideo') else None
+        self.dynamic_pak_id = data.get('dynamicPakId')
+        self.item_preview_hero_path = data.get('itemPreviewHeroPath')
         self.display_asset_path = data.get('displayAssetPath')
         self.definition_path = data.get('definitionPath')
         self.path = data.get('path')
@@ -215,4 +223,5 @@ class BrCosmeticVariantOption:
         self.tag = data.get('tag')
         self.name = data.get('name')
         self.image = BrCosmeticImage(data.get('image'))
+        self.unlock_requirements = data.get('unlockRequirements')
         self.raw_data = data
