@@ -17,9 +17,9 @@ class News:
     """
 
     def __init__(self, data):
-        self.br = GameModeNews(data.get('br'))
-        self.stw = GameModeNews(data.get('stw'))
-        self.creative = GameModeNews(data.get('creative'))
+        self.br = GameModeNews(data.get('br')) if data.get('br') else None
+        self.stw = GameModeNews(data.get('stw')) if data.get('stw') else None
+        self.creative = GameModeNews(data.get('creative')) if data.get('creative') else None
         self.raw_data = data
 
 
